Re-exports
pub use xvc_config as config;pub use xvc_core as core;pub use xvc_ecs as ecs;pub use xvc_file as file;pub use xvc_logging as logging;pub use xvc_pipeline as pipeline;
Macros
- Debugging macro to print the given expression and its value, with the module, function and line number
Functions
- Run xvc in another process with
argsinxvc_root_opt.