The main dispatching functions for the entire XVC CLI
Re-exports
pub use xvc_config as config;pub use xvc_core as core;pub use xvc_ecs as ecs;pub use xvc_file as file;pub use xvc_logging as logging;pub use xvc_pipeline as pipeline;Macros
Functions
Ensures
xvc is the first element in args, and runs [cli::test_dispatch] after parsing them.
It allows to run commands out of xvc directories.
For detailed logs, set verbosity to XvcVerbosity::Trace