pub fn test_dispatch(
    xvc_root_opt: Option<&XvcRoot>,
    args: Vec<&str>,
    verbosity: XvcVerbosity
) -> Result<String>
Ensures xvc is the first element in args, and runs [cli::test_dispatch] after parsing them. It allows to run commands out of xvc directories. For detailed logs, set verbosity to XvcVerbosity::Trace